==> ticketbooth_1.0.1.orig.tar.gz: ticketbooth-1.0.1/README.md <==
<!--
Copyright (C) 2023 Alessandro Iepure

SPDX-License-Identifier: GPL-3.0-or-later
-->

<div align="center">
  <h1><img src="./data/icons/hicolor/scalable/apps/me.iepure.Ticketbooth.svg" height="64"/><br>Ticket Booth</h1>
  <h4>Keep track of your favorite shows</h4>
</div>
<div align="center">
  <a href="https://github.com/aleiepure/ticketbooth/actions/workflows/build-x86.yaml" title="Build Flatpak status">
    <img src="https://github.com/aleiepure/ticketbooth/actions/workflows/build-x86.yaml/badge.svg"/>
  </a>
  <a href="https://github.com/aleiepure/ticketbooth/blob/main/LICENSES/GPL-3.0-or-later.txt" title="GPL-3 License">
    <img src="https://img.shields.io/badge/License-GPL--3.0-blue.svg">
  </a>
   <a href="https://api.reuse.software/info/github.com/aleiepure/ticketbooth" title="REUSE compliance">
    <img src="https://api.reuse.software/badge/github.com/aleiepure/ticketbooth" />
  </a>
  <a href="https://hosted.weblate.org/engage/ticket-booth/">
    <img src="https://hosted.weblate.org/widget/ticket-booth/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://stopthemingmy.app" title="Please do not theme this app">
    <img src="https://stopthemingmy.app/badge.svg" />
  </a>
  <br />
  <a href="#features">Features</a> ·
  <a href="#install">Install</a> ·
  <a href="#contribute">Contribute</a> ·
  <a href="#license">License</a>
</div>

## Features
Ticket Booth allows you to build your watchlist of movies and TV Shows, keep track of watched titles, and find information about the latest releases.

Ticket Booth does not allow you to watch or download content.
This app uses the TMDB API but is not endorsed or certified by TMDB.

## Install
<a href='https://flathub.org/apps/me.iepure.Ticketbooth'>
  <img width='240' alt='Download on Flathub' src='https://dl.flathub.org/assets/badges/flathub-badge-en.png'/>
</a> <br>

Builds from the main branch are available as artifacts on the [Actions page](https://github.com/aleiepure/ticketbooth/actions).\
To build from source see [Building](./CONTRIBUTING.md#building).

## Contribute
This project is translated via [Weblate](https://hosted.weblate.org/engage/ticket-booth/).\
<a href="https://hosted.weblate.org/engage/ticket-booth/">
  <img src="https://hosted.weblate.org/widget/ticket-booth/horizontal-auto.svg" alt="Translation status" />
</a>

See [Contributing](./CONTRIBUTING.md) to learn more.

## License
Copyright (C) 2023 Alessandro Iepure\
This application comes with absolutely no warranty. See the GNU General Public License, version 3 or later for details. A [copy of the license](./LICENSES/GPL-3.0-or-later.txt)
can be found in the [LICENSES/](./LICENSES/) folder.

Most symbolic icons are copyright of the GNOME Project.\
The libraries used are the copyright of the respective copyright holders.\
This project is [REUSE](https://reuse.software/) compliant.

==> ticketbooth_1.0.3.1.orig.tar.gz: ticketbooth-1.0.3.1/README.md <==
<!--
Copyright (C) 2023 Alessandro Iepure

SPDX-License-Identifier: GPL-3.0-or-later
-->

<div align="center">
  <h1><img src="./data/icons/hicolor/scalable/apps/me.iepure.Ticketbooth.svg" height="64"/><br>Ticket Booth</h1>
  <h4>Keep track of your favorite shows</h4>
</div>
<div align="center">
  <a href="https://github.com/aleiepure/ticketbooth/actions/workflows/build-x86.yaml" title="Build Flatpak status">
    <img src="https://github.com/aleiepure/ticketbooth/actions/workflows/build-x86.yaml/badge.svg"/>
  </a>
  <a href="https://github.com/aleiepure/ticketbooth/blob/main/LICENSES/GPL-3.0-or-later.txt" title="GPL-3 License">
    <img src="https://img.shields.io/badge/License-GPL--3.0-blue.svg">
  </a>
   <a href="https://api.reuse.software/info/github.com/aleiepure/ticketbooth" title="REUSE compliance">
    <img src="https://api.reuse.software/badge/github.com/aleiepure/ticketbooth" />
  </a>
  <a href="https://hosted.weblate.org/engage/ticket-booth/">
    <img src="https://hosted.weblate.org/widget/ticket-booth/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://stopthemingmy.app" title="Please do not theme this app">
    <img src="https://stopthemingmy.app/badge.svg" />
  </a>
  <br />
  <a href="#features">Features</a> ·
  <a href="#install">Install</a> ·
  <a href="#contribute">Contribute</a> ·
  <a href="#license">License</a>
</div>

## Features
Ticket Booth allows you to build your watchlist of movies and TV Shows, keep track of watched titles, and find information about the latest releases.

Ticket Booth does not allow you to watch or download content.
This app uses the TMDB API but is not endorsed or certified by TMDB.

## Install
<a href='https://flathub.org/apps/me.iepure.Ticketbooth'>
  <img width='240' alt='Download on Flathub' src='https://dl.flathub.org/assets/badges/flathub-badge-en.png'/>
</a> <br>

Builds from the main branch are available as artifacts on the [Actions page](https://github.com/aleiepure/ticketbooth/actions).\
To build from source see [Building](./CONTRIBUTING.md#building).

## Contribute
This project is translated ~~via [Weblate](https://hosted.weblate.org/engage/ticket-booth/).~~ temporally via `.po` files. \
<a href="https://hosted.weblate.org/engage/ticket-booth/">
  <img src="https://hosted.weblate.org/widget/ticket-booth/horizontal-auto.svg" alt="Translation status" />
</a>

See [Contributing](./CONTRIBUTING.md) to learn more.

## License
Copyright (C) 2023 Alessandro Iepure\
This application comes with absolutely no warranty. See the GNU General Public License, version 3 or later for details. A [copy of the license](./LICENSES/GPL-3.0-or-later.txt)
can be found in the [LICENSES/](./LICENSES/) folder.

Most symbolic icons are copyright of the GNOME Project.\
The libraries used are the copyright of the respective copyright holders.\
This project is [REUSE](https://reuse.software/) compliant.
